@@ -17,7 +17,7 @@ def scrape(
     verbosity: int = typer.Option(
         0, "-v", "--verbose", count=True, help="Verbosity level 0-2"
     ),
-):
+) -> None:
     if schema_file:
         with open(schema_file) as f:
             schema = f.read()
@@ -35,10 +35,10 @@ def scrape(
     if css:
         scraper.preprocessors.append(CSS(css))
     result = scraper(url)
-    typer.echo(json.dumps(result))
+    typer.echo(json.dumps(result.data))
 
 
-def main():
+def main() -> None:
     typer.run(scrape)
 
 
