@@ -1,24 +1,22 @@
 import lxml.html
+import lxml.html.clean
+from typing import Callable
 
 
-class Preprocessor:
-    """
-    Preprocessor interface: given a node, returns a list of nodes.
-    """
-
-    def __call__(self, node: lxml.html.HtmlElement) -> list[lxml.html.HtmlElement]:
-        raise NotImplementedError
+Preprocessor = Callable[[lxml.html.HtmlElement], list[lxml.html.HtmlElement]]
 
 
-class CleanHTML(Preprocessor):
+class CleanHTML:
     """
     Given HTML, return a cleaned HTML string.
 
     Uses lxml.html.clean.Cleaner.
     """
 
-    def __init__(self, **kwargs):
-        self.cleaner = lxml.html.clean.Cleaner(**kwargs)
+    def __init__(self, **kwargs: dict) -> None:
+        # need to set remove_unknown_tags to False since lxml.html seems to
+        # have an outdated list of tags
+        self.cleaner = lxml.html.clean.Cleaner(**kwargs, remove_unknown_tags=False)
 
     def __str__(self) -> str:
         return "CleanHTML"
@@ -28,7 +26,7 @@ class CleanHTML(Preprocessor):
         return [doc]
 
 
-class XPath(Preprocessor):
+class XPath:
     """
     Given an XPath selector, return a list of nodes.
     """
@@ -43,7 +41,7 @@ class XPath(Preprocessor):
         return node.xpath(self.xpath)
 
 
-class CSS(Preprocessor):
+class CSS:
     """
     Given a CSS selector, return a list of nodes.
     """
